@@ -1,7 +1,7 @@
 package Switch::Right;
 
 use 5.036;
-our $VERSION = '0.000002';
+our $VERSION = '0.000003';
 
 use experimental qw< builtin refaliasing try >;
 use builtin      qw< true false is_bool blessed created_as_number reftype >;
@@ -677,6 +677,16 @@ multi smartmatch ($left, $right) {
                          || !smartmatch($left->{$key}, $right->{$key});  # ...every value must match
         }
         return true;
+
+    # Every other REF/REF comparison, just checks for the same address..
+    FORMATFORMAT:;
+    IOIO:;
+    SCALARSCALAR:;
+    VSTRINGVSTRING:;
+    REFREF:;
+    GLOBGLOB:;
+    LVALUELVALUE:;
+        return $left == $right;
 }
 
 # Junctive smartmatching of the RHS list...
@@ -821,7 +831,7 @@ Switch::Right -  Switch and smartmatch done right this time
 
 =head1 VERSION
 
-This document describes Switch::Right version 0.000002
+This document describes Switch::Right version 0.000003
 
 
 =head1 SYNOPSIS
